@@ -38,7 +38,7 @@ class DetectorAnalyzeResult:
     analyzed_at: float
 
 
-AnalyzeResultCallback = Callable[[list[DetectorAnalyzeResult]], Coroutine[Any, DetectorAnalyzeResult, Any]]
+AnalyzeResultCallback = Callable[[list[DetectorAnalyzeResult]], Coroutine[Any, list[DetectorAnalyzeResult], Any]]
 
 
 class DetectorKafkaConnector:
